@@ -1,14 +1,14 @@
 """
 Type annotations for comprehendmedical service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
     ```python
-    from mypy_boto3_comprehendmedical.literals import AttributeName
+    from mypy_boto3_comprehendmedical.literals import AttributeNameType
 
-    data: AttributeName = "DIAGNOSIS"
+    data: AttributeNameType = "DIAGNOSIS"
     ```
 """
 import sys
@@ -20,26 +20,26 @@ else:
 
 
 __all__ = (
-    "AttributeName",
-    "EntitySubType",
-    "EntityType",
-    "ICD10CMAttributeType",
-    "ICD10CMEntityCategory",
-    "ICD10CMEntityType",
-    "ICD10CMRelationshipType",
-    "ICD10CMTraitName",
-    "JobStatus",
-    "LanguageCode",
-    "RelationshipType",
-    "RxNormAttributeType",
-    "RxNormEntityCategory",
-    "RxNormEntityType",
-    "RxNormTraitName",
+    "AttributeNameType",
+    "EntitySubTypeType",
+    "EntityTypeType",
+    "ICD10CMAttributeTypeType",
+    "ICD10CMEntityCategoryType",
+    "ICD10CMEntityTypeType",
+    "ICD10CMRelationshipTypeType",
+    "ICD10CMTraitNameType",
+    "JobStatusType",
+    "LanguageCodeType",
+    "RelationshipTypeType",
+    "RxNormAttributeTypeType",
+    "RxNormEntityCategoryType",
+    "RxNormEntityTypeType",
+    "RxNormTraitNameType",
 )
 
 
-AttributeName = Literal["DIAGNOSIS", "NEGATION", "SIGN", "SYMPTOM"]
-EntitySubType = Literal[
+AttributeNameType = Literal["DIAGNOSIS", "NEGATION", "SIGN", "SYMPTOM"]
+EntitySubTypeType = Literal[
     "ACUITY",
     "ADDRESS",
     "AGE",
@@ -75,7 +75,7 @@ EntitySubType = Literal[
     "TREATMENT_NAME",
     "URL",
 ]
-EntityType = Literal[
+EntityTypeType = Literal[
     "ANATOMY",
     "MEDICAL_CONDITION",
     "MEDICATION",
@@ -83,7 +83,7 @@ EntityType = Literal[
     "TEST_TREATMENT_PROCEDURE",
     "TIME_EXPRESSION",
 ]
-ICD10CMAttributeType = Literal[
+ICD10CMAttributeTypeType = Literal[
     "ACUITY",
     "DIRECTION",
     "QUALITY",
@@ -92,11 +92,11 @@ ICD10CMAttributeType = Literal[
     "TIME_EXPRESSION",
     "TIME_TO_DX_NAME",
 ]
-ICD10CMEntityCategory = Literal["MEDICAL_CONDITION"]
-ICD10CMEntityType = Literal["DX_NAME", "TIME_EXPRESSION"]
-ICD10CMRelationshipType = Literal["OVERLAP", "SYSTEM_ORGAN_SITE"]
-ICD10CMTraitName = Literal["DIAGNOSIS", "NEGATION", "SIGN", "SYMPTOM"]
-JobStatus = Literal[
+ICD10CMEntityCategoryType = Literal["MEDICAL_CONDITION"]
+ICD10CMEntityTypeType = Literal["DX_NAME", "TIME_EXPRESSION"]
+ICD10CMRelationshipTypeType = Literal["OVERLAP", "SYSTEM_ORGAN_SITE"]
+ICD10CMTraitNameType = Literal["DIAGNOSIS", "NEGATION", "SIGN", "SYMPTOM"]
+JobStatusType = Literal[
     "COMPLETED",
     "FAILED",
     "IN_PROGRESS",
@@ -105,8 +105,8 @@ JobStatus = Literal[
     "STOP_REQUESTED",
     "SUBMITTED",
 ]
-LanguageCode = Literal["en"]
-RelationshipType = Literal[
+LanguageCodeType = Literal["en"]
+RelationshipTypeType = Literal[
     "ACUITY",
     "ADMINISTERED_VIA",
     "DIRECTION",
@@ -126,9 +126,9 @@ RelationshipType = Literal[
     "TEST_VALUE",
     "WITH_DOSAGE",
 ]
-RxNormAttributeType = Literal[
+RxNormAttributeTypeType = Literal[
     "DOSAGE", "DURATION", "FORM", "FREQUENCY", "RATE", "ROUTE_OR_MODE", "STRENGTH"
 ]
-RxNormEntityCategory = Literal["MEDICATION"]
-RxNormEntityType = Literal["BRAND_NAME", "GENERIC_NAME"]
-RxNormTraitName = Literal["NEGATION"]
+RxNormEntityCategoryType = Literal["MEDICATION"]
+RxNormEntityTypeType = Literal["BRAND_NAME", "GENERIC_NAME"]
+RxNormTraitNameType = Literal["NEGATION"]
